# Deepfake Detector

Deepfake Detector is a Python library designed for detecting deepfake content in images and videos. Leveraging advanced machine learning techniques, it provides an easy-to-use interface for real-time and batch processing of media files.

## Features

- Real-time Deepfake Detection: Analyze live video feeds to detect deepfake content.
- Batch Processing: Process multiple images and videos to classify them as real or fake.
- Customizable Thresholds: Adjust detection sensitivity to suit your specific needs.

## Installation

You can install the `deepfake_detector` package using pip:

```bash
pip install deepfake_detector
```

## Usage

### For Video Detection

Detect deepfake content in a video file. You can provide a video file path or use a webcam.

```python
from deepfake_detector import DeepfakeDetector

# Create a detector object with a custom threshold
detector = DeepfakeDetector(threshold=0.5)

# Detect deepfakes in a video file
detector.detect_from_video('path_to_video.mp4')

# Use webcam (source=0) for live detection
detector.detect_from_video(source=0)
```

### For Image Detection

Detect deepfake content in a single image.

```python
from deepfake_detector import DeepfakeDetector

# Create a detector object with a custom threshold
detector = DeepfakeDetector(threshold=0.5)

# Detect deepfakes in an image
result = detector.detect_from_image('path_to_image.jpg')
print(f'The image is classified as: {"FAKE" if result > 0.5 else "REAL"}')
```

### Customizing Detection Threshold

You can set the threshold to control the sensitivity of the detection.

```python
# Example with a higher sensitivity threshold
detector = DeepfakeDetector(threshold=0.7)
```

## Paper Reference

For more detailed information about the techniques used in this library, please refer to the following research paper:

- **Title**: [Deepfake Detection Using the Rate of Change between Frames Based on Computer Vision](https://www.mdpi.com/1424-8220/21/21/7367)
- **Journal**: MDPI Sensors
- **Abstract**: This paper explores advanced methods for detecting deepfake media using convolutional neural networks (CNNs). The study provides a comprehensive analysis of various techniques and their effectiveness in identifying manipulated content.

## Contributing

If you would like to contribute to the development of this library, please follow these steps:

1. Fork the repository on GitHub.
2. Create a new branch for your changes.
3. Commit your changes with descriptive messages.
4. Push your changes to your fork.
5. Submit a pull request to the main repository.

## Contact

For any questions or feedback, please contact:

- **Author**: Adupa Nithin Sai
- **Email**: [adupanithinsai@gmail.com](mailto:adupanithinsai@gmail.com)
- **GitHub**: [https://github.com/saiadupa/Deepfake-detector](https://github.com/saiadupa/Deepfake-detector)

---

Thank you for using Deepfake Detector. We hope you find it useful for your deepfake detection needs!
```
